;; Generated package description from org.el  -*- no-byte-compile: t -*-
(define-package "org" "9.4.6" "Outline-based notes management and organizer" '((emacs "24.3")) :keywords '("outlines" "hypermedia" "calendar" "wp") :authors '(("Carsten Dominik" . "carsten.dominik@gmail.com")) :maintainer '("Bastien Guerry" . "bzg@gnu.org") :url "https://orgmode.org")
